@@ -379,14 +379,24 @@ class Scanner(object):
 						else:
 							arches.add((keyword, arch, (arch, keyword)))
 					else:
+						# For ebuilds with stable keywords, check if the
+						# dependencies are satisfiable for unstable
+						# configurations, since use.stable.mask is not
+						# applied for unstable configurations (see bug
+						# 563546).
 						if keyword == "*":
 							for expanded_arch in self.profiles:
 								if expanded_arch == "**":
 									continue
 								arches.add(
 									(keyword, expanded_arch, (expanded_arch,)))
+								arches.add(
+									(keyword, expanded_arch,
+										(expanded_arch, "~" + expanded_arch)))
 						else:
 							arches.add((keyword, keyword, (keyword,)))
+							arches.add((keyword, keyword,
+								(keyword, "~" + keyword)))
 				if not arches:
 					# Use an empty profile for checking dependencies of
 					# packages that have empty KEYWORDS.
